==> s3stepfunctions-1.159.0-sources.jar: software/amazon/awsconstructs/services/s3stepfunctions/S3ToStepfunctions.java <==
package software.amazon.awsconstructs.services.s3stepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.63.2 (build a8a8833)", date = "2022-08-01T14:28:00.013Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.s3stepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-s3-stepfunctions.S3ToStepfunctions")
public class S3ToStepfunctions extends software.amazon.awscdk.core.Construct {

    protected S3ToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3ToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public S3ToStepfunctions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps.Builder();
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param deployCloudTrail Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3. This parameter is required.
         */
        public Builder deployCloudTrail(final java.lang.Boolean deployCloudTrail) {
            this.props.deployCloudTrail(deployCloudTrail);
            return this;
        }

        /**
         * Optional user provided eventRuleProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventRuleProps Optional user provided eventRuleProps to override the defaults. This parameter is required.
         */
        public Builder eventRuleProps(final software.amazon.awscdk.services.events.RuleProps eventRuleProps) {
            this.props.eventRuleProps(eventRuleProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * The Amazon EventBridge property must be enabled in the existing bucket for the construct to work.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps Optional user provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions build() {
            return new software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> s3stepfunctions-2.29.0-sources.jar: software/amazon/awsconstructs/services/s3stepfunctions/S3ToStepfunctions.java <==
package software.amazon.awsconstructs.services.s3stepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-04T22:46:37.032Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.s3stepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-s3-stepfunctions.S3ToStepfunctions")
public class S3ToStepfunctions extends software.constructs.Construct {

    protected S3ToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3ToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public S3ToStepfunctions(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctionsProps.Builder();
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param deployCloudTrail Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3. This parameter is required.
         */
        public Builder deployCloudTrail(final java.lang.Boolean deployCloudTrail) {
            this.props.deployCloudTrail(deployCloudTrail);
            return this;
        }

        /**
         * Optional user provided eventRuleProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventRuleProps Optional user provided eventRuleProps to override the defaults. This parameter is required.
         */
        public Builder eventRuleProps(final software.amazon.awscdk.services.events.RuleProps eventRuleProps) {
            this.props.eventRuleProps(eventRuleProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * The Amazon EventBridge property must be enabled in the existing bucket for the construct to work.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps Optional user provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions build() {
            return new software.amazon.awsconstructs.services.s3stepfunctions.S3ToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
